==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/client/render/entity/FrostSpellEntityRenderer.java <==
package com.github.thedeathlycow.frostiful.client.render.entity;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.entity.SpellEntity;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_8012;
import net.minecraft.class_897;

@Environment(EnvType.CLIENT)
public class FrostSpellEntityRenderer extends class_897<SpellEntity> {

    private static final class_2960 TEXTURE = Frostiful.id("textures/entity/frost_spell.png");
    private static final class_1921 LAYER;

    public FrostSpellEntityRenderer(class_5617.class_5618 ctx) {
        super(ctx);
    }

    public void render(
            SpellEntity dragonFireballEntity,
            float yaw, float tickDelta,
            class_4587 matrixStack,
            class_4597 vertexConsumerProvider,
            int light
    ) {
        matrixStack.method_22903();
        matrixStack.method_22905(2.0F, 2.0F, 2.0F);
        matrixStack.method_22907(this.field_4676.method_24197());
        class_4587.class_4665 entry = matrixStack.method_23760();
        class_4588 vertexConsumer = vertexConsumerProvider.getBuffer(LAYER);
        produceVertex(vertexConsumer, entry, light, 0.0F, 0, 0, 1);
        produceVertex(vertexConsumer, entry, light, 1.0F, 0, 1, 1);
        produceVertex(vertexConsumer, entry, light, 1.0F, 1, 1, 0);
        produceVertex(vertexConsumer, entry, light, 0.0F, 1, 0, 0);
        matrixStack.method_22909();
        super.method_3936(dragonFireballEntity, yaw, tickDelta, matrixStack, vertexConsumerProvider, light);
    }

    private static void produceVertex(
            class_4588 vertexConsumer,
            class_4587.class_4665 matrix,
            int light,
            float x, int z,
            int textureU, int textureV
    ) {
        vertexConsumer.method_56824(matrix, x - 0.5F, z - 0.25F, 0.0F)
                .method_39415(class_8012.field_42973)
                .method_22913(textureU, textureV)
                .method_22922(class_4608.field_21444)
                .method_60803(light)
                .method_60831(matrix, 0.0F, 1.0F, 0.0F);
    }

    @Override
    public class_2960 getTextureLocation(SpellEntity entity) {
        return TEXTURE;
    }

    static {
        LAYER = class_1921.method_23578(TEXTURE);
    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/client/render/entity/FrostSpellEntityRenderer.java <==
package com.github.thedeathlycow.frostiful.client.render.entity;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.entity.FrostSpellEntity;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10017;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_8012;
import net.minecraft.class_897;

@Environment(EnvType.CLIENT)
public class FrostSpellEntityRenderer extends class_897<FrostSpellEntity, class_10017> {

    private static final class_2960 TEXTURE = Frostiful.id("textures/entity/frost_spell.png");
    private static final class_1921 LAYER = class_1921.method_23578(TEXTURE);

    public FrostSpellEntityRenderer(class_5617.class_5618 ctx) {
        super(ctx);
    }

    @Override
    public class_10017 method_55269() {
        return new class_10017();
    }

    public void method_3936(
            class_10017 state,
            class_4587 matrixStack,
            class_4597 vertexConsumerProvider,
            int light
    ) {
        matrixStack.method_22903();
        matrixStack.method_22905(2.0F, 2.0F, 2.0F);
        matrixStack.method_22907(this.field_4676.method_24197());
        class_4587.class_4665 entry = matrixStack.method_23760();
        class_4588 vertexConsumer = vertexConsumerProvider.getBuffer(LAYER);
        produceVertex(vertexConsumer, entry, light, 0.0F, 0, 0, 1);
        produceVertex(vertexConsumer, entry, light, 1.0F, 0, 1, 1);
        produceVertex(vertexConsumer, entry, light, 1.0F, 1, 1, 0);
        produceVertex(vertexConsumer, entry, light, 0.0F, 1, 0, 0);
        matrixStack.method_22909();
        super.method_3936(state, matrixStack, vertexConsumerProvider, light);
    }

    private static void produceVertex(
            class_4588 vertexConsumer,
            class_4587.class_4665 matrix,
            int light,
            float x, int z,
            int textureU, int textureV
    ) {
        vertexConsumer.method_56824(matrix, x - 0.5F, z - 0.25F, 0.0F)
                .method_39415(class_8012.field_42973)
                .method_22913(textureU, textureV)
                .method_22922(class_4608.field_21444)
                .method_60803(light)
                .method_60831(matrix, 0.0F, 1.0F, 0.0F);
    }
}
